@@ -11,7 +11,7 @@
 
 void bind_utility();
 void bind_fingerprint();
-void bind_big_number();
+void bind_sha1_hash();
 void bind_session();
 void bind_entry();
 void bind_torrent_info();
@@ -22,7 +22,6 @@ void bind_session_settings();
 void bind_version();
 void bind_alert();
 void bind_datetime();
-void bind_torrent();
 void bind_peer_info();
 void bind_ip_filter();
 void bind_magnet_uri();
@@ -38,20 +37,17 @@ BOOST_PYTHON_MODULE(libtorrent)
     bind_error_code();
     bind_utility();
     bind_fingerprint();
-    bind_big_number();
+    bind_sha1_hash();
     bind_entry();
+    bind_torrent_handle();
     bind_session();
     bind_torrent_info();
-#if TORRENT_USE_WSTRING
     bind_unicode_string_conversion();
-#endif
-    bind_torrent_handle();
     bind_torrent_status();
     bind_session_settings();
     bind_version();
     bind_alert();
     bind_datetime();
-    bind_torrent();
     bind_peer_info();
     bind_ip_filter();
     bind_magnet_uri();
