@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2007, Arvid Norberg
+Copyright (c) 2007-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -33,9 +33,13 @@ POSSIBILITY OF SUCH DAMAGE.
 #ifndef TORRENT_BANDWIDTH_CHANNEL_HPP_INCLUDED
 #define TORRENT_BANDWIDTH_CHANNEL_HPP_INCLUDED
 
+#include "libtorrent/aux_/disable_warnings_push.hpp"
+
 #include <boost/integer_traits.hpp>
 #include <boost/cstdint.hpp>
 
+#include "libtorrent/aux_/disable_warnings_pop.hpp"
+
 #include "libtorrent/assert.hpp"
 
 namespace libtorrent {
@@ -43,7 +47,7 @@ namespace libtorrent {
 // member of peer_connection
 struct TORRENT_EXTRA_EXPORT bandwidth_channel
 {
-	static const int inf = boost::integer_traits<int>::const_max;
+	static boost::int32_t const inf = boost::integer_traits<boost::int32_t>::const_max;
 
 	bandwidth_channel();
 
@@ -51,8 +55,9 @@ struct TORRENT_EXTRA_EXPORT bandwidth_channel
 	void throttle(int limit);
 	int throttle() const
 	{
-		TORRENT_ASSERT_VAL(m_limit < INT_MAX, m_limit);
-		return int(m_limit);
+		TORRENT_ASSERT_VAL(m_limit >= 0, m_limit);
+		TORRENT_ASSERT_VAL(m_limit < inf, m_limit);
+		return m_limit;
 	}
 
 	int quota_left() const;
@@ -64,6 +69,19 @@ struct TORRENT_EXTRA_EXPORT bandwidth_channel
 	void return_quota(int amount);
 	void use_quota(int amount);
 
+	// this is an optimization. If there is more than one second
+	// of quota built up in this channel, just apply it right away
+	// instead of introducing a delay to split it up evenly. This
+	// should especially help in situations where a single peer
+	// has a capacity under the rate limit, but would otherwise be
+	// held back by the latency of getting bandwidth from the limiter
+	bool need_queueing(int amount)
+	{
+		if (m_quota_left - amount < m_limit) return true;
+		m_quota_left -= amount;
+		return false;
+	}
+
 	// used as temporary storage while distributing
 	// bandwidth
 	int tmp;
@@ -79,10 +97,9 @@ private:
 
 	// the limit is the number of bytes
 	// per second we are allowed to use.
-	boost::int64_t m_limit;
+	boost::int32_t m_limit;
 };
 
 }
 
 #endif
-
