@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2005-2016, Arvid Norberg
+Copyright (c) 2005-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,6 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <boost/config.hpp>
 #include <boost/asio/detail/config.hpp>
 #include <boost/version.hpp>
-#include <boost/detail/endian.hpp>
 #include <stdio.h> // for snprintf
 #include <limits.h> // for IOV_MAX
 
@@ -624,7 +623,7 @@ int snprintf(char* buf, int len, char const* fmt, ...)
 #endif
 
 #if !defined(TORRENT_READ_HANDLER_MAX_SIZE)
-# ifdef _GLIBCXX_DEBUG
+# if defined _GLIBCXX_DEBUG || !defined NDEBUG
 #  define TORRENT_READ_HANDLER_MAX_SIZE 400
 # else
 // if this is not divisible by 8, we're wasting space
@@ -633,7 +632,7 @@ int snprintf(char* buf, int len, char const* fmt, ...)
 #endif
 
 #if !defined(TORRENT_WRITE_HANDLER_MAX_SIZE)
-# ifdef _GLIBCXX_DEBUG
+# if defined _GLIBCXX_DEBUG || !defined NDEBUG
 #  define TORRENT_WRITE_HANDLER_MAX_SIZE 400
 # else
 // if this is not divisible by 8, we're wasting space
