@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2007-2014, Arvid Norberg
+Copyright (c) 2007-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -30,65 +30,77 @@ POSSIBILITY OF SUCH DAMAGE.
 
 */
 
-#ifndef TORRENT_DISK_BUFFER_POOL
-#define TORRENT_DISK_BUFFER_POOL
-
-#include <boost/utility.hpp>
+#ifndef TORRENT_DISK_BUFFER_POOL_HPP
+#define TORRENT_DISK_BUFFER_POOL_HPP
 
 #include "libtorrent/config.hpp"
-#include "libtorrent/thread.hpp"
-#include "libtorrent/session_settings.hpp"
-#include "libtorrent/allocator.hpp"
+
+#include "libtorrent/aux_/disable_warnings_push.hpp"
+
+#include <vector>
+#include <boost/shared_ptr.hpp>
+#include <boost/function.hpp>
+#include <boost/utility.hpp>
 
 #ifndef TORRENT_DISABLE_POOL_ALLOCATOR
 #include <boost/pool/pool.hpp>
 #endif
 
-#ifdef TORRENT_DISK_STATS
-#include <fstream>
+#if defined TORRENT_DEBUG || TORRENT_RELEASE_ASSERTS
+#include <set>
 #endif
 
-#if TORRENT_USE_ASSERTS || TORRENT_DISK_STATS
-#include <boost/unordered_map.hpp>
-#endif
+#include "libtorrent/aux_/disable_warnings_pop.hpp"
+
+#include "libtorrent/thread.hpp"
+#include "libtorrent/io_service_fwd.hpp"
+#include "libtorrent/file.hpp" // for iovec_t
 
 namespace libtorrent
 {
+	namespace aux { struct session_settings; }
+	class alert;
+	struct disk_observer;
+
 	struct TORRENT_EXTRA_EXPORT disk_buffer_pool : boost::noncopyable
 	{
-		disk_buffer_pool(int block_size);
-#if TORRENT_USE_ASSERTS
+		disk_buffer_pool(int block_size, io_service& ios
+			, boost::function<void()> const& trigger_trim);
 		~disk_buffer_pool();
-#endif
 
-#if TORRENT_USE_ASSERTS || TORRENT_DISK_STATS
+#if TORRENT_USE_ASSERTS
 		bool is_disk_buffer(char* buffer
 			, mutex::scoped_lock& l) const;
 		bool is_disk_buffer(char* buffer) const;
 #endif
 
 		char* allocate_buffer(char const* category);
+		char* allocate_buffer(bool& exceeded, boost::shared_ptr<disk_observer> o
+			, char const* category);
 		void free_buffer(char* buf);
 		void free_multiple_buffers(char** bufvec, int numbufs);
 
+		int allocate_iovec(file::iovec_t* iov, int iov_len);
+		void free_iovec(file::iovec_t* iov, int iov_len);
+
 		int block_size() const { return m_block_size; }
 
-#ifdef TORRENT_STATS
-		int disk_allocations() const
-		{ return m_allocations; }
-#endif
-
-#ifdef TORRENT_DISK_STATS
-		std::ofstream m_disk_access_log;
-#endif
-
 		void release_memory();
 
-		int in_use() const { return m_in_use; }
+		boost::uint32_t in_use() const
+		{
+			mutex::scoped_lock l(m_pool_mutex);
+			return m_in_use;
+		}
+		boost::uint32_t num_to_evict(int num_needed = 0);
+		bool exceeded_max_size() const { return m_exceeded_max_size; }
+
+		void set_settings(aux::session_settings const& sett, error_code& ec);
 
 	protected:
 
 		void free_buffer_impl(char* buf, mutex::scoped_lock& l);
+		char* allocate_buffer_impl(mutex::scoped_lock& l, char const* category);
 
 		// number of bytes per block. The BitTorrent
 		// protocol defines the block size to 16 KiB.
@@ -97,16 +109,55 @@ namespace libtorrent
 		// number of disk buffers currently allocated
 		int m_in_use;
 
-		session_settings m_settings;
+		// cache size limit
+		int m_max_use;
+
+		// if we have exceeded the limit, we won't start
+		// allowing allocations again until we drop below
+		// this low watermark
+		int m_low_watermark;
+
+		// if we exceed the max number of buffers, we start
+		// adding up callbacks to this queue. Once the number
+		// of buffers in use drops below the low watermark,
+		// we start calling these functions back
+		std::vector<boost::weak_ptr<disk_observer> > m_observers;
+
+		// callback used to tell the cache it needs to free up some blocks
+		boost::function<void()> m_trigger_cache_trim;
+
+		// set to true to throttle more allocations
+		bool m_exceeded_max_size;
+
+		// this is the main thread io_service. Callbacks are
+		// posted on this in order to have them execute in
+		// the main thread.
+		io_service& m_ios;
 
 	private:
 
+		void check_buffer_level(mutex::scoped_lock& l);
+
 		mutable mutex m_pool_mutex;
 
+		int m_cache_buffer_chunk_size;
+
+#if TORRENT_HAVE_MMAP && !defined TORRENT_NO_DEPRECATE
+		// the file descriptor of the cache mmap file
+		int m_cache_fd;
+		// the pointer to the block of virtual address space
+		// making up the mmapped cache space
+		char* m_cache_pool;
+		// list of block indices that are not in use. block_index
+		// times 0x4000 + m_cache_pool is the address where the
+		// corresponding memory lives
+		std::vector<int> m_free_list;
+#endif
+
 #ifndef TORRENT_DISABLE_POOL_ALLOCATOR
 		// if this is true, all buffers are allocated
 		// from m_pool. If this is false, all buffers
-		// are allocated using page_aligned_allocator.
+		// are allocated using malloc.
 		// if the settings change to prefer the other
 		// allocator, this bool will not switch over
 		// to match the settings until all buffers have
@@ -117,29 +168,27 @@ namespace libtorrent
 		// or once the client goes idle for a while.
 		bool m_using_pool_allocator;
 
+		// this is the actual user setting
+		bool m_want_pool_allocator;
+
 		// memory pool for read and write operations
 		// and disk cache
-		boost::pool<page_aligned_allocator> m_pool;
+		boost::pool<> m_pool;
 #endif
 
-#if defined TORRENT_DISK_STATS || defined TORRENT_STATS
-		int m_allocations;
-#endif
-#ifdef TORRENT_DISK_STATS
-	public:
-		void rename_buffer(char* buf, char const* category);
-	protected:
-		boost::unordered_map<std::string, int> m_categories;
-		boost::unordered_map<char*, std::string> m_buf_to_category;
-		std::ofstream m_log;
-	private:
+		// this is specifically exempt from release_asserts
+		// since it's a quite costly check. Only for debug
+		// builds.
+#if defined TORRENT_DEBUG
+		std::set<char*> m_buffers_in_use;
 #endif
 #if TORRENT_USE_ASSERTS
 		int m_magic;
+		bool m_settings_set;
 #endif
 	};
 
 }
 
-#endif // TORRENT_DISK_BUFFER_POOL
+#endif // TORRENT_DISK_BUFFER_POOL_HPP
 
