@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2008-2014, Arvid Norberg
+Copyright (c) 2008-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -35,23 +35,23 @@ POSSIBILITY OF SUCH DAMAGE.
 
 #include <boost/version.hpp>
 #include "libtorrent/config.hpp"
+#include "libtorrent/string_util.hpp" // for allocate_string_copy
+#include <stdlib.h> // free
+
+#include "libtorrent/aux_/disable_warnings_push.hpp"
 
 #if defined TORRENT_WINDOWS || defined TORRENT_CYGWIN
 // asio assumes that the windows error codes are defined already
 #include <winsock2.h>
 #endif
 
-#if BOOST_VERSION < 103500
-#include <asio/error_code.hpp>
-#else
 #include <boost/system/error_code.hpp>
-#endif
+#include <boost/asio/error.hpp>
 
-#include "libtorrent/string_util.hpp" // for allocate_string_copy
-#include <stdlib.h> // free
+#include "libtorrent/aux_/disable_warnings_pop.hpp"
 
 #ifndef BOOST_SYSTEM_NOEXCEPT
-#define BOOST_SYSTEM_NOEXCEPT throw()
+#define BOOST_SYSTEM_NOEXCEPT TORRENT_EXCEPTION_THROW_SPECIFIER
 #endif
 
 namespace libtorrent
@@ -59,8 +59,10 @@ namespace libtorrent
 
 	namespace errors
 	{
-		// libtorrent uses boost.system's ``error_code`` class to represent errors. libtorrent has
-		// its own error category get_libtorrent_category() whith the error codes defined by error_code_enum.
+		// libtorrent uses boost.system's ``error_code`` class to represent
+		// errors. libtorrent has its own error category
+		// libtorrent_category() with the error codes defined by
+		// error_code_enum.
 		enum error_code_enum
 		{
 			// Not an error
@@ -113,7 +115,7 @@ namespace libtorrent
 			invalid_entry_type,
 			// The specified URI does not contain a valid info-hash
 			missing_info_hash_in_uri,
-			// One of the files in the torrent was unexpectadly small. This
+			// One of the files in the torrent was unexpectedly small. This
 			// might be caused by files being changed by an external process
 			file_too_short,
 			// The URL used an unknown protocol. Currently ``http`` and
@@ -124,7 +126,7 @@ namespace libtorrent
 			url_parse_error,
 			// The peer sent a 'piece' message of length 0
 			peer_sent_empty_piece,
-			// A bencoded structure was currupt and failed to be parsed
+			// A bencoded structure was corrupt and failed to be parsed
 			parse_failed,
 			// The fast resume file was missing or had an invalid file version
 			// tag
@@ -218,7 +220,7 @@ namespace libtorrent
 			invalid_reject,
 			// The peer sent an invalid allow fast-message
 			invalid_allow_fast,
-			// The peer sent an invalid extesion message ID
+			// The peer sent an invalid extension message ID
 			invalid_extended,
 			// The peer sent an invalid message ID
 			invalid_message,
@@ -254,7 +256,7 @@ namespace libtorrent
 			packet_too_large,
 
 			reserved,
-			
+
 			// The web server responded with an error
 			http_error,
 			// The web server response is missing a location header
@@ -262,7 +264,7 @@ namespace libtorrent
 			// The web seed redirected to a path that no longer matches the
 			// .torrent directory structure
 			invalid_redirection,
-			// The connection was closed becaused it redirected to a different
+			// The connection was closed because it redirected to a different
 			// URL
 			redirecting,
 			// The HTTP range header is invalid
@@ -316,9 +318,9 @@ namespace libtorrent
 			// This happens for magnet links before they have downloaded the
 			// metadata, and also torrents added by URL.
 			no_metadata,
-			// The peer sent an invalid ``dont_have`` message. The dont have
+			// The peer sent an invalid ``dont_have`` message. The don't have
 			// message is an extension to allow peers to advertise that the
-			// no longer has a piece they previously had.                      
+			// no longer has a piece they previously had.
 			invalid_dont_have,
 			// The peer tried to connect to an SSL torrent without connecting
 			// over SSL.
@@ -329,6 +331,9 @@ namespace libtorrent
 			// the torrent is not an SSL torrent, and the operation requires
 			// an SSL torrent
 			not_an_ssl_torrent,
+			// peer was banned because its listen port is within a banned port
+			// range, as specified by the port_filter.
+			banned_by_port_filter,
 
 
 			// The NAT-PMP router responded with an unsupported protocol version
@@ -364,7 +369,7 @@ namespace libtorrent
 			// The 'blocks per piece' entry is invalid in the resume data file
 			invalid_blocks_per_piece,
 			// The resume file is missing the 'slots' entry, which is required
-			// for torrents with compact allocation
+			// for torrents with compact allocation. *DEPRECATED*
 			missing_slots,
 			// The resume file contains more slots than the torrent
 			too_many_slots,
@@ -375,8 +380,12 @@ namespace libtorrent
 			// The pieces on disk needs to be re-ordered for the specified
 			// allocation mode. This happens if you specify sparse allocation
 			// and the files on disk are using compact storage. The pieces needs
-			// to be moved to their right position
+			// to be moved to their right position. *DEPRECATED*
 			pieces_need_reorder,
+			// this error is returned when asking to save resume data and
+			// specifying the flag to only save when there's anything new to save
+			// (torrent_handle::only_if_modified) and there wasn't anything changed.
+			resume_data_not_modified,
 
 
 
@@ -393,8 +402,10 @@ namespace libtorrent
 
 			// The URL specified an i2p address, but no i2p router is configured
 			no_i2p_router = 160,
+			// i2p acceptor is not available yet, can't announce without endpoint
+			no_i2p_endpoint = 161,
+
 
-			
 
 			// The tracker URL doesn't support transforming it into a scrape
 			// URL. i.e. it doesn't contain "announce.
@@ -467,96 +478,109 @@ namespace libtorrent
 
 	} // namespace errors
 
-#if BOOST_VERSION < 103500
-	typedef asio::error_code error_code;
-	// hidden
-	inline asio::error::error_category get_posix_category()
-	{ return asio::error::system_category; }
-	// hidden
-	inline asio::error::error_category get_system_category()
-	{ return asio::error::system_category; }
-
-	// hidden
-	boost::system::error_category const& get_libtorrent_category()
-	{
-		static ::asio::error::error_category libtorrent_category(20);
-		return libtorrent_category;
-	}
-
-	// hidden
-	boost::system::error_category const& get_http_category()
-	{
-		static ::asio::error::error_category http_category(21);
-		return http_category;
-	}
-
-#else
-
 	// return the instance of the libtorrent_error_category which
 	// maps libtorrent error codes to human readable error messages.
-	TORRENT_EXPORT boost::system::error_category& get_libtorrent_category();
+	TORRENT_EXPORT boost::system::error_category& libtorrent_category();
 
 	// returns the error_category for HTTP errors
-	TORRENT_EXPORT boost::system::error_category& get_http_category();
+	TORRENT_EXPORT boost::system::error_category& http_category();
 
 	using boost::system::error_code;
-
-	// hidden
-	inline boost::system::error_category const& get_system_category()
-#if BOOST_VERSION < 104400
-	{ return boost::system::get_system_category(); }
-#else
-	{ return boost::system::system_category(); }
-#endif
-
-	// hidden
-	inline boost::system::error_category const& get_posix_category()
-#if BOOST_VERSION < 103600
-	{ return boost::system::get_posix_category(); }
-#elif BOOST_VERSION < 104400
-	{ return boost::system::get_generic_category(); }
-#else
-	{ return boost::system::generic_category(); }
-#endif // BOOST_VERSION < 103600
-#endif // BOOST_VERSION < 103500
+	using boost::system::error_condition;
 
 	// internal
-	inline boost::system::error_category const& generic_category()
-	{ return get_posix_category(); }
+	using boost::system::generic_category;
+	using boost::system::system_category;
+
+#ifndef TORRENT_NO_DEPRECATE
+	TORRENT_DEPRECATED TORRENT_EXPORT
+	boost::system::error_category& get_libtorrent_category();
+	TORRENT_DEPRECATED TORRENT_EXPORT
+	boost::system::error_category& get_http_category();
+#endif
 
 #ifndef BOOST_NO_EXCEPTIONS
-	struct TORRENT_EXPORT libtorrent_exception: std::exception
+	struct TORRENT_EXPORT libtorrent_exception : std::exception
 	{
 		libtorrent_exception(error_code const& s): m_error(s), m_msg(0) {}
-		virtual const char* what() const throw();
-		virtual ~libtorrent_exception() throw();
+		virtual const char* what() const TORRENT_EXCEPTION_THROW_SPECIFIER;
+		virtual ~libtorrent_exception() TORRENT_EXCEPTION_THROW_SPECIFIER;
+#if __cplusplus >= 201103L
+		libtorrent_exception(libtorrent_exception const&) = default;
+		libtorrent_exception& operator=(libtorrent_exception const&) = default;
+#endif
 		error_code error() const { return m_error; }
 	private:
 		error_code m_error;
 		mutable char* m_msg;
 	};
 #endif
-}
 
-#if BOOST_VERSION >= 103500
+	// used by storage to return errors
+	// also includes which underlying file the
+	// error happened on
+	struct TORRENT_EXPORT storage_error
+	{
+		storage_error(): file(-1), operation(0) {}
+		storage_error(error_code e): ec(e), file(-1), operation(0) {}
+
+		operator bool() const { return ec.value() != 0; }
+
+		// the error that occurred
+		error_code ec;
+
+		// the file the error occurred on
+		boost::int32_t file:24;
+
+		// A code from file_operation_t enum, indicating what
+		// kind of operation failed.
+		boost::uint32_t operation:8;
+
+		enum file_operation_t {
+			none,
+			stat,
+			mkdir,
+			open,
+			rename,
+			remove,
+			copy,
+			read,
+			write,
+			fallocate,
+			alloc_cache_piece,
+			partfile_move,
+			partfile_read,
+			partfile_write,
+			check_resume,
+			hard_link
+		};
+
+		// Returns a string literal representing the file operation
+		// that failed. If there were no failure, it returns
+		// an empty string.
+		char const* operation_str() const
+		{
+			static char const* ops[] =
+			{
+				"", "stat", "mkdir", "open", "rename", "remove", "copy"
+				, "read", "write", "fallocate", "allocate cache piece"
+				, "partfile move", "partfile read", "partfile write"
+				, "check resume", "hard_link"
+			};
+			return ops[operation];
+		}
+	};
+
+}
 
 namespace boost { namespace system {
 
 	template<> struct is_error_code_enum<libtorrent::errors::error_code_enum>
 	{ static const bool value = true; };
 
-	template<> struct is_error_condition_enum<libtorrent::errors::error_code_enum>
-	{ static const bool value = true; };
-
 	template<> struct is_error_code_enum<libtorrent::errors::http_errors>
 	{ static const bool value = true; };
-
-	template<> struct is_error_condition_enum<libtorrent::errors::http_errors>
-	{ static const bool value = true; };
 } }
 
-#endif // BOOST_VERSION
-
-
 #endif
 
