@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2009-2016, Arvid Norberg
+Copyright (c) 2009-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -149,7 +149,7 @@ private:
 	// send and receive buffer
 	std::vector<char> m_buffer;
 	char const* m_id;
-	int m_command; // 0 = connect, 1 = accept
+	command_t m_command;
 	std::string m_dest;
 	std::string m_name_lookup;
 
@@ -162,7 +162,7 @@ private:
 		read_name_lookup_response
 	};
 
-	int m_state;
+	state_t m_state;
 #if TORRENT_USE_ASSERTS
 	int m_magic;
 #endif
