@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2009-2014, Arvid Norberg
+Copyright (c) 2009-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #define Protocol Protocol_
 #endif
 
-#ifdef _MSC_VER
-#pragma warning(push, 1)
-#endif
+#include "libtorrent/aux_/disable_warnings_push.hpp"
 
 #include <boost/version.hpp>
 
@@ -48,25 +46,25 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <winsock2.h>
 #endif
 
-#if BOOST_VERSION < 103500
-#include <asio/io_service.hpp>
-#else
 #include <boost/asio/io_service.hpp>
+#include <boost/version.hpp>
+
+#if defined TORRENT_BUILD_SIMULATOR
+#include "simulator/simulator.hpp"
 #endif
 
-#ifdef _MSC_VER
-#pragma warning(pop)
-#endif
+#include "libtorrent/aux_/disable_warnings_pop.hpp"
 
-#ifdef __OBJC__ 
+#ifdef __OBJC__
 #undef Protocol
 #endif
 
+#include "libtorrent/io_service_fwd.hpp"
+
 namespace libtorrent
 {
-
-#if BOOST_VERSION < 103500
-	typedef ::asio::io_service io_service;
+#if defined TORRENT_BUILD_SIMULATOR
+	typedef sim::asio::io_service io_service;
 #else
 	typedef boost::asio::io_service io_service;
 #endif
