@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2005-2016, Arvid Norberg
+Copyright (c) 2005-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -41,10 +41,16 @@ POSSIBILITY OF SUCH DAMAGE.
 #include <vector>
 
 #include <boost/limits.hpp>
-#include <boost/utility.hpp>
 #include <boost/cstdint.hpp>
 #include <boost/tuple/tuple.hpp>
 
+#include <boost/version.hpp>
+#if BOOST_VERSION >= 106700
+#include <boost/next_prior.hpp>
+#else
+#include <boost/utility.hpp>
+#endif
+
 #include "libtorrent/aux_/disable_warnings_pop.hpp"
 
 #include "libtorrent/address.hpp"
@@ -66,6 +72,12 @@ struct ip_range
 	Addr first;
 	Addr last;
 	boost::uint32_t flags;
+	friend bool operator==(ip_range const& lhs, ip_range const& rhs)
+	{
+		return lhs.first == rhs.first
+			&& lhs.last == rhs.last
+			&& lhs.flags == rhs.flags;
+	}
 };
 
 namespace detail
