@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2007-2014, Un Shyam & Arvid Norberg
+Copyright (c) 2007-2018, Un Shyam & Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -30,18 +30,13 @@ POSSIBILITY OF SUCH DAMAGE.
 
 */
 
-#ifndef TORRENT_DISABLE_ENCRYPTION
+#if !defined(TORRENT_DISABLE_ENCRYPTION) && !defined(TORRENT_DISABLE_EXTENSIONS)
 
 #ifndef TORRENT_PE_CRYPTO_HPP_INCLUDED
 #define TORRENT_PE_CRYPTO_HPP_INCLUDED
 
 #include "libtorrent/config.hpp"
 
-#ifdef TORRENT_USE_GCRYPT
-#include <gcrypt.h>
-#elif defined TORRENT_USE_OPENSSL
-#include <openssl/rc4.h>
-#else
 // RC4 state from libtomcrypt
 struct rc4 {
 	int x, y;
@@ -50,11 +45,18 @@ struct rc4 {
 
 void TORRENT_EXTRA_EXPORT rc4_init(const unsigned char* in, unsigned long len, rc4 *state);
 unsigned long TORRENT_EXTRA_EXPORT rc4_encrypt(unsigned char *out, unsigned long outlen, rc4 *state);
-#endif
 
+#include "libtorrent/aux_/disable_warnings_push.hpp"
+#include <boost/asio/buffer.hpp>
+#include "libtorrent/aux_/disable_warnings_pop.hpp"
+
+#include "libtorrent/receive_buffer.hpp"
 #include "libtorrent/peer_id.hpp" // For sha1_hash
+#include "libtorrent/extensions.hpp"
 #include "libtorrent/assert.hpp"
 
+#include <list>
+
 namespace libtorrent
 {
 	class TORRENT_EXTRA_EXPORT dh_key_exchange
@@ -73,7 +75,7 @@ namespace libtorrent
 		char const* get_secret() const { return m_dh_shared_secret; }
 
 		sha1_hash const& get_hash_xor_mask() const { return m_xor_mask; }
-		
+
 	private:
 
 		int get_local_key_size() const
@@ -87,112 +89,57 @@ namespace libtorrent
 
 	struct encryption_handler
 	{
-		virtual void set_incoming_key(unsigned char const* key, int len) = 0;
-		virtual void set_outgoing_key(unsigned char const* key, int len) = 0;
-		virtual void encrypt(char* pos, int len) = 0;
-		virtual void decrypt(char* pos, int len) = 0;
-		virtual ~encryption_handler() {}
-	};
+		int encrypt(std::vector<boost::asio::mutable_buffer>& iovec);
+		int decrypt(crypto_receive_buffer& recv_buffer, std::size_t& bytes_transferred);
 
-	struct rc4_handler : encryption_handler
-	{
-	public:
-		// Input longkeys must be 20 bytes
-		rc4_handler()
-			: m_encrypt(false)
-			, m_decrypt(false)
-		{
-#ifdef TORRENT_USE_GCRYPT
-			gcry_cipher_open(&m_rc4_incoming, GCRY_CIPHER_ARCFOUR, GCRY_CIPHER_MODE_STREAM, 0);
-			gcry_cipher_open(&m_rc4_outgoing, GCRY_CIPHER_ARCFOUR, GCRY_CIPHER_MODE_STREAM, 0);
-#endif
-		};
+		bool switch_send_crypto(boost::shared_ptr<crypto_plugin> crypto
+			, int pending_encryption);
 
-		void set_incoming_key(unsigned char const* key, int len)
-		{
-			m_decrypt = true;
-#ifdef TORRENT_USE_GCRYPT
-			gcry_cipher_close(m_rc4_incoming);
-			gcry_cipher_open(&m_rc4_incoming, GCRY_CIPHER_ARCFOUR, GCRY_CIPHER_MODE_STREAM, 0);
-			gcry_cipher_setkey(m_rc4_incoming, key, len);
-#elif defined TORRENT_USE_OPENSSL
-			RC4_set_key(&m_remote_key, len, key);
-#else
-			rc4_init(key, len, &m_rc4_incoming);
-#endif
-			// Discard first 1024 bytes
-			char buf[1024];
-			decrypt(buf, 1024);
-		}
-		
-		void set_outgoing_key(unsigned char const* key, int len)
-		{
-			m_encrypt = true;
-#ifdef TORRENT_USE_GCRYPT
-			gcry_cipher_close(m_rc4_outgoing);
-			gcry_cipher_open(&m_rc4_outgoing, GCRY_CIPHER_ARCFOUR, GCRY_CIPHER_MODE_STREAM, 0);
-			gcry_cipher_setkey(m_rc4_outgoing, key, len);
-#elif defined TORRENT_USE_OPENSSL
-			RC4_set_key(&m_local_key, len, key);
-#else
-			rc4_init(key, len, &m_rc4_outgoing);
-#endif
-			// Discard first 1024 bytes
-			char buf[1024];
-			encrypt(buf, 1024);
-		}
-		
-		~rc4_handler()
-		{
-#ifdef TORRENT_USE_GCRYPT
-			gcry_cipher_close(m_rc4_incoming);
-			gcry_cipher_close(m_rc4_outgoing);
-#endif
-		};
+		void switch_recv_crypto(boost::shared_ptr<crypto_plugin> crypto
+			, crypto_receive_buffer& recv_buffer);
 
-		void encrypt(char* pos, int len)
+		bool is_send_plaintext() const
 		{
-			if (!m_encrypt) return;
-
-			TORRENT_ASSERT(len >= 0);
-			TORRENT_ASSERT(pos);
-
-#ifdef TORRENT_USE_GCRYPT
-			gcry_cipher_encrypt(m_rc4_outgoing, pos, len, 0, 0);
-#elif defined TORRENT_USE_OPENSSL
-			RC4(&m_local_key, len, (const unsigned char*)pos, (unsigned char*)pos);
-#else
-			rc4_encrypt((unsigned char*)pos, len, &m_rc4_outgoing);
-#endif
+			return m_send_barriers.empty() || m_send_barriers.back().next != INT_MAX;
 		}
 
-		void decrypt(char* pos, int len)
+		bool is_recv_plaintext() const
 		{
-			if (!m_decrypt) return;
-
-			TORRENT_ASSERT(len >= 0);
-			TORRENT_ASSERT(pos);
-
-#ifdef TORRENT_USE_GCRYPT
-			gcry_cipher_decrypt(m_rc4_incoming, pos, len, 0, 0);
-#elif defined TORRENT_USE_OPENSSL
-			RC4(&m_remote_key, len, (const unsigned char*)pos, (unsigned char*)pos);
-#else
-			rc4_encrypt((unsigned char*)pos, len, &m_rc4_incoming);
-#endif
+			return m_dec_handler.get() == NULL;
 		}
 
 	private:
-#ifdef TORRENT_USE_GCRYPT
-		gcry_cipher_hd_t m_rc4_incoming;
-		gcry_cipher_hd_t m_rc4_outgoing;
-#elif defined TORRENT_USE_OPENSSL
-		RC4_KEY m_local_key; // Key to encrypt outgoing data
-		RC4_KEY m_remote_key; // Key to decrypt incoming data
-#else
+		struct barrier
+		{
+			barrier(boost::shared_ptr<crypto_plugin> plugin, int n)
+				: enc_handler(plugin), next(n) {}
+			boost::shared_ptr<crypto_plugin> enc_handler;
+			// number of bytes to next barrier
+			int next;
+		};
+		std::list<barrier> m_send_barriers;
+		boost::shared_ptr<crypto_plugin> m_dec_handler;
+	};
+
+	struct TORRENT_EXTRA_EXPORT rc4_handler : crypto_plugin
+	{
+	public:
+		rc4_handler();
+
+		// Input keys must be 20 bytes
+		void set_incoming_key(unsigned char const* key, int len) TORRENT_OVERRIDE;
+		void set_outgoing_key(unsigned char const* key, int len) TORRENT_OVERRIDE;
+
+		int encrypt(std::vector<boost::asio::mutable_buffer>& buf) TORRENT_OVERRIDE;
+		void decrypt(std::vector<boost::asio::mutable_buffer>& buf
+			, int& consume
+			, int& produce
+			, int& packet_size) TORRENT_OVERRIDE;
+
+	private:
 		rc4 m_rc4_incoming;
 		rc4 m_rc4_outgoing;
-#endif
+
 		// determines whether or not encryption and decryption is enabled
 		bool m_encrypt;
 		bool m_decrypt;
