@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2016, Arvid Norberg
+Copyright (c) 2003-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -365,7 +365,7 @@ namespace libtorrent
 		int picker_options() const;
 
 		void prefer_contiguous_blocks(int num)
-		{ m_prefer_contiguous_blocks = (std::min)(num, 255); }
+		{ m_prefer_contiguous_blocks = num; }
 
 		bool request_large_blocks() const
 		{ return m_request_large_blocks; }
@@ -501,11 +501,6 @@ namespace libtorrent
 		// finish the connection attempt
 		bool is_connecting() const { return m_connecting; }
 
-		// This is called for every peer right after the upload
-		// bandwidth has been distributed among them
-		// It will reset the used bandwidth to 0.
-		void reset_upload_quota();
-
 		// trust management.
 		virtual void received_valid_data(int index);
 		// returns false if the peer should not be
@@ -807,7 +802,6 @@ namespace libtorrent
 		peer_connection& operator=(peer_connection const&);
 
 		void do_update_interest();
-		int preferred_caching() const;
 		void fill_send_buffer();
 		void on_disk_read_complete(disk_io_job const* j, peer_request r
 			, time_point issue_time);
@@ -1081,7 +1075,7 @@ namespace libtorrent
 		// by sending choke, unchoke.
 		int m_num_invalid_requests;
 
-		// if [0] is -1, superseeding is not active. If it is >= 0
+		// if [0] is -1, super-seeding is not active. If it is >= 0
 		// this is the piece that is available to this peer. Only
 		// these two pieces can be downloaded from us by this peer.
 		// This will remain the current piece for this peer until
@@ -1134,7 +1128,7 @@ namespace libtorrent
 		// if it is 0, the download rate limit setting
 		// will be used to determine if whole pieces
 		// are preferred.
-		boost::uint8_t m_prefer_contiguous_blocks;
+		int m_prefer_contiguous_blocks;
 
 		// this is the number of times this peer has had
 		// a request rejected because of a disk I/O failure.
