@@ -25,9 +25,7 @@
 /*
  * See puff.c for purpose and usage.
  */
-#include <boost/cstdint.hpp>
-
 int puff(unsigned char *dest,           /* pointer to destination pointer */
-         boost::uint32_t *destlen,        /* amount of output space */
-         unsigned char *source,         /* pointer to source data pointer */
-         boost::uint32_t *sourcelen);     /* amount of input available */
+         unsigned long *destlen,        /* amount of output space */
+         const unsigned char *source,   /* pointer to source data pointer */
+         unsigned long *sourcelen);     /* amount of input available */
