@@ -161,6 +161,8 @@ namespace libtorrent
 
 		boost::uint32_t key;
 		int num_want;
+
+		address_v4 ipv4;
 #if TORRENT_USE_IPV6
 		address_v6 ipv6;
 #endif
@@ -284,7 +286,7 @@ namespace libtorrent
 		virtual void on_timeout(error_code const& ec) = 0;
 		virtual ~timeout_handler() {}
 
-		io_service& get_io_service() { return m_timeout.get_io_service(); }
+		io_service& get_io_service() { return lt::get_io_service(m_timeout); }
 
 	private:
 
