@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2006-2016, Arvid Norberg
+Copyright (c) 2006-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -39,6 +39,7 @@ POSSIBILITY OF SUCH DAMAGE.
 // convert_to_native and convert_from_native
 #if TORRENT_USE_WSTRING || defined TORRENT_WINDOWS
 
+#include <boost/cstdint.hpp>
 #include <string>
 #include <cwchar>
 
@@ -71,6 +72,9 @@ namespace libtorrent
 		const std::string &utf8, std::wstring &wide);
 	TORRENT_EXTRA_EXPORT utf8_conv_result_t wchar_utf8(
 		const std::wstring &wide, std::string &utf8);
+
+	TORRENT_EXTRA_EXPORT std::pair<boost::int32_t, int>
+		parse_utf8_codepoint(char const* str, int len);
 }
 #endif // !BOOST_NO_STD_WSTRING
 
