@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2007-2016, Arvid Norberg
+Copyright (c) 2007-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -169,6 +169,8 @@ namespace libtorrent
 		tcp::socket test(ios);
 		error_code ec;
 		test.open(tcp::v6(), ec);
+		if (ec) return false;
+		test.bind(tcp::endpoint(address_v6::from_string("::1"), 0), ec);
 		return !bool(ec);
 #endif
 	}
