@@ -84,10 +84,10 @@ namespace libtorrent
 		// is greater than the send quanta, and it has been unchoked for at least one minute
 		// then it's done with its upload slot, and we can de-prioritize it
 		bool c1_quota_complete = !lhs->is_choked()
-			&& c1 > t1->torrent_file().piece_length() * pieces
+			&& c1 > boost::int64_t(t1->torrent_file().piece_length()) * pieces
 			&& aux::time_now() - lhs->time_of_last_unchoke() > minutes(1);
 		bool c2_quota_complete = !rhs->is_choked()
-			&& c2 > t2->torrent_file().piece_length() * pieces
+			&& c2 > boost::int64_t(t2->torrent_file().piece_length()) * pieces
 			&& aux::time_now() - rhs->time_of_last_unchoke() > minutes(1);
 
 		// if c2 has completed a quanta, it should be de-prioritized
