@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2016, Arvid Norberg
+Copyright (c) 2003-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -640,7 +640,7 @@ namespace libtorrent
 
 			if (i->connection != 0)
 			{
-				bool self_connection =
+				bool const self_connection =
 					i->connection->remote() == c.local_endpoint()
 					|| i->connection->local_endpoint() == c.remote();
 
@@ -671,57 +671,41 @@ namespace libtorrent
 					// disconnect the same one, we need a consistent rule to
 					// select which one.
 
-					bool outgoing1 = c.is_outgoing();
+					bool const outgoing1 = c.is_outgoing();
 
-					// for this, we compare our endpoints (IP and port)
-					// and whoever has the lower IP,port should be the
-					// one keeping its outgoing connection. Since outgoing
-					// ports are selected at random by the OS, we need
-					// to be careful to only look at the target end of a
-					// connection for the endpoint.
+					// for this, we compare our ports and whoever has the lower port
+					// should be the one keeping its outgoing connection. Since
+					// outgoing ports are selected at random by the OS, we need to
+					// be careful to only look at the target end of a connection for
+					// the endpoint.
 
-					int our_port = outgoing1 ? i->connection->local_endpoint().port() : c.local_endpoint().port();
-					int other_port= outgoing1 ? c.remote().port() : i->connection->remote().port();
+					int const our_port = outgoing1 ? i->connection->local_endpoint().port() : c.local_endpoint().port();
+					int const other_port = outgoing1 ? c.remote().port() : i->connection->remote().port();
+
+					// decide which peer connection to disconnect
+					// if the ports are equal, pick on at random
+					bool const disconnect1 = ((our_port < other_port) && !outgoing1)
+						|| ((our_port > other_port) && outgoing1)
+						|| ((our_port == other_port) && randint(2));
 
-					if (our_port < other_port)
-					{
 #ifndef TORRENT_DISABLE_LOGGING
-						c.peer_log(peer_log_alert::info, "DUPLICATE_PEER_RESOLUTION"
-							, "\"%d\" < \"%d\"", our_port, other_port);
-						i->connection->peer_log(peer_log_alert::info, "DUPLICATE_PEER_RESOLUTION"
-							, "\"%d\" < \"%d\"", our_port, other_port);
+					c.peer_log(peer_log_alert::info, "DUPLICATE_PEER_RESOLUTION"
+						, "our: %d other: %d disconnecting: %s"
+						, our_port, other_port, disconnect1 ? "yes" : "no");
+					i->connection->peer_log(peer_log_alert::info, "DUPLICATE_PEER_RESOLUTION"
+						, "our: %d other: %d disconnecting: %s"
+						, our_port, other_port, disconnect1 ? "no" : "yes");
 #endif
 
-						// we should keep our outgoing connection
-						if (!outgoing1)
-						{
-							c.disconnect(errors::duplicate_peer_id, op_bittorrent);
-							return false;
-						}
-						TORRENT_ASSERT(m_locked_peer == NULL);
-						m_locked_peer = i;
-						i->connection->disconnect(errors::duplicate_peer_id, op_bittorrent);
-						m_locked_peer = NULL;
-					}
-					else
+					if (disconnect1)
 					{
-#ifndef TORRENT_DISABLE_LOGGING
-						c.peer_log(peer_log_alert::info, "DUPLICATE_PEER_RESOLUTION"
-							, "\"%d\" >= \"%d\"", our_port, other_port);
-						i->connection->peer_log(peer_log_alert::info, "DUPLICATE_PEER_RESOLUTION"
-							, "\"%d\" >= \"%d\"", our_port, other_port);
-#endif
-						// they should keep their outgoing connection
-						if (outgoing1)
-						{
-							c.disconnect(errors::duplicate_peer_id, op_bittorrent);
-							return false;
-						}
-						TORRENT_ASSERT(m_locked_peer == NULL);
-						m_locked_peer = i;
-						i->connection->disconnect(errors::duplicate_peer_id, op_bittorrent);
-						m_locked_peer = NULL;
+						c.disconnect(errors::duplicate_peer_id, op_bittorrent);
+						return false;
 					}
+					TORRENT_ASSERT(m_locked_peer == NULL);
+					m_locked_peer = i;
+					i->connection->disconnect(errors::duplicate_peer_id, op_bittorrent);
+					m_locked_peer = NULL;
 				}
 			}
 
