@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2016, Arvid Norberg
+Copyright (c) 2003-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #include "libtorrent/aux_/session_call.hpp"
 #include "libtorrent/torrent.hpp"
 #include "libtorrent/lazy_entry.hpp"
+#include "libtorrent/peer_class_type_filter.hpp"
 
 #ifdef __GNUC__
 #pragma GCC diagnostic push
@@ -579,12 +580,12 @@ namespace libtorrent
 		p.set_str(settings_pack::peer_fingerprint, id.to_string());
 		apply_settings(p);
 	}
-#endif
 
 	peer_id session_handle::id() const
 	{
-		return TORRENT_SYNC_CALL_RET(peer_id, get_peer_id);
+		return TORRENT_SYNC_CALL_RET(peer_id, deprecated_get_peer_id);
 	}
+#endif
 
 	void session_handle::set_key(int key)
 	{
@@ -611,11 +612,21 @@ namespace libtorrent
 		TORRENT_ASYNC_CALL1(set_peer_class_filter, f);
 	}
 
+	ip_filter session_handle::get_peer_class_filter() const
+	{
+		return TORRENT_SYNC_CALL_RET(ip_filter, get_peer_class_filter);
+	}
+
 	void session_handle::set_peer_class_type_filter(peer_class_type_filter const& f)
 	{
 		TORRENT_ASYNC_CALL1(set_peer_class_type_filter, f);
 	}
 
+	peer_class_type_filter session_handle::get_peer_class_type_filter() const
+	{
+		return TORRENT_SYNC_CALL_RET(peer_class_type_filter, get_peer_class_type_filter);
+	}
+
 	int session_handle::create_peer_class(char const* name)
 	{
 		return TORRENT_SYNC_CALL_RET1(int, create_peer_class, name);
