@@ -15,7 +15,7 @@ changelog at the end of the file.
 
 #include "libtorrent/sha1.hpp"
 
-#include <boost/detail/endian.hpp> // for BIG_ENDIAN and LITTLE_ENDIAN macros
+#include <boost/predef/other/endian.h>
 
 typedef boost::uint32_t u32;
 typedef boost::uint8_t u8;
@@ -164,7 +164,7 @@ namespace
 #endif
 	}
 
-#if !defined BOOST_BIG_ENDIAN && !defined BOOST_LITTLE_ENDIAN
+#if !BOOST_ENDIAN_BIG_BYTE && !BOOST_ENDIAN_LITTLE_BYTE
 	bool is_big_endian()
 	{
 		u32 test = 1;
@@ -193,9 +193,9 @@ void SHA1_update(sha_ctx* context, u8 const* data, u32 len)
 {
 	// GCC standard defines for endianness
 	// test with: cpp -dM /dev/null
-#if defined BOOST_BIG_ENDIAN
+#if BOOST_ENDIAN_BIG_BYTE
 	internal_update<big_endian_blk0>(context, data, len);
-#elif defined BOOST_LITTLE_ENDIAN
+#elif BOOST_ENDIAN_LITTLE_BYTE
 	internal_update<little_endian_blk0>(context, data, len);
 #else
 	// select different functions depending on endianess
