@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2006-2016, MassaRoddel, Arvid Norberg
+Copyright (c) 2006-2018, MassaRoddel, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -337,6 +337,7 @@ namespace libtorrent { namespace
 			p = pex_msg.dict_find_string("added");
 			bdecode_node pf = pex_msg.dict_find_string("added.f");
 
+			bool peers_added = false;
 #ifndef TORRENT_DISABLE_LOGGING
 			if (p) num_added += p.string_length() / 6;
 #endif
@@ -363,6 +364,7 @@ namespace libtorrent { namespace
 					if (j != m_peers.end() && *j == v) continue;
 					m_peers.insert(j, v);
 					m_torrent.add_peer(adr, peer_info::pex, flags);
+					peers_added = true;
 				}
 			}
 
@@ -416,7 +418,8 @@ namespace libtorrent { namespace
 					if (j != m_peers6.end() && *j == v) continue;
 					m_peers6.insert(j, v);
 					m_torrent.add_peer(adr, peer_info::pex, flags);
-				} 
+					peers_added = true;
+				}
 			}
 #endif
 #ifndef TORRENT_DISABLE_LOGGING
@@ -425,6 +428,8 @@ namespace libtorrent { namespace
 #endif
 
 			m_pc.stats_counters().inc_stats_counter(counters::num_incoming_pex);
+
+			if (peers_added) m_torrent.do_connect_boost();
 			return true;
 		}
 
