@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2003-2016, Arvid Norberg
+Copyright (c) 2003-2018, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -86,16 +86,16 @@ web_peer_connection::web_peer_connection(peer_connection_args const& pack
 	shared_ptr<torrent> tor = pack.tor.lock();
 	TORRENT_ASSERT(tor);
 
-	// we always prefer downloading 1 MiB chunks
-	// from web seeds, or whole pieces if pieces
-	// are larger than a MiB
-	int preferred_size = 1024 * 1024;
+	// if the web server is known not to support keep-alive. request 4MiB
+	// but we want to have at least piece size to prevent block based requests
+	int const min_size = std::max((web.supports_keepalive ? 1 : 4) * 1024 * 1024,
+		tor->torrent_file().piece_length());
 
-	// if the web server is known not to support keep-alive.
-	// request even larger blocks at a time
-	if (!web.supports_keepalive) preferred_size *= 4;
+	// we prefer downloading large chunks from web seeds,
+	// but still want to be able to split requests
+	int const preferred_size = std::max(min_size, m_settings.get_int(settings_pack::urlseed_max_request_bytes));
 
-	prefer_contiguous_blocks((std::max)(preferred_size / tor->block_size(), 1));
+	prefer_contiguous_blocks(preferred_size / tor->block_size());
 
 	boost::shared_ptr<torrent> t = associated_torrent().lock();
 	bool const single_file_request = t->torrent_file().num_files() == 1;
@@ -563,7 +563,7 @@ void web_peer_connection::handle_error(int bytes_left)
 			, error_msg);
 	}
 	received_bytes(0, bytes_left);
-	disconnect(error_code(m_parser.status_code(), get_http_category()), op_bittorrent, 1);
+	disconnect(error_code(m_parser.status_code(), http_category()), op_bittorrent, 1);
 	return;
 }
 
@@ -978,9 +978,16 @@ void web_peer_connection::incoming_payload(char const* buf, int len)
 				, "piece: %d start: %d len: %d"
 				, front_request.piece, front_request.start, front_request.length);
 #endif
+
+			// Make a copy of the request and pop it off the queue before calling
+			// incoming_piece because that may lead to a call to disconnect()
+			// which will clear the request queue and invalidate any references
+			// to the request
+			peer_request const front_request_copy = front_request;
 			m_requests.pop_front();
 
-			incoming_piece(front_request, &m_piece[0]);
+			incoming_piece(front_request_copy, &m_piece[0]);
+
 			m_piece.clear();
 		}
 	}
