@@ -44,6 +44,8 @@ namespace libtorrent
 	class file_storage;
 }
 
+EXPORT boost::shared_ptr<lt::torrent_info> generate_torrent();
+
 EXPORT int print_failures();
 EXPORT unsigned char random_byte();
 
@@ -65,7 +67,9 @@ EXPORT libtorrent::sha1_hash rand_hash();
 EXPORT std::map<std::string, boost::int64_t> get_counters(libtorrent::session& s);
 
 EXPORT libtorrent::alert const* wait_for_alert(
-	libtorrent::session& ses, int type, char const* name = "", int num = 1);
+	libtorrent::session& ses, int type, char const* name = ""
+	, int num = 1
+	, lt::time_duration timeout = lt::seconds(10));
 
 EXPORT void print_ses_rate(float time
 	, libtorrent::torrent_status const* st1
@@ -76,7 +80,7 @@ EXPORT bool print_alerts(libtorrent::session& ses, char const* name
 	, bool allow_disconnects = false
 	, bool allow_no_torrents = false
 	, bool allow_failed_fastresume = false
-	, boost::function<bool(libtorrent::alert const*)> predicate
+	, boost::function<bool(libtorrent::alert const*)> const& predicate
 		= boost::function<bool(libtorrent::alert const*)>()
 	, bool no_output = false);
 
